use Job_Start
go

CREATE TABLE ApplicationDatabases (
       AppId                int NOT NULL,
       DatabaseId           int NOT NULL
)
go


ALTER TABLE ApplicationDatabases
       ADD PRIMARY KEY CLUSTERED (AppId ASC, DatabaseId ASC)
go


CREATE TABLE Applications (
       AppId                int NOT NULL,
       AppName              char(40) NULL
)
go


ALTER TABLE Applications
       ADD PRIMARY KEY CLUSTERED (AppId ASC)
go


CREATE TABLE Databases (
       DatabaseId           int NOT NULL,
       DatabaseName         char(40) NULL
)
go


ALTER TABLE Databases
       ADD PRIMARY KEY CLUSTERED (DatabaseId ASC)
go


CREATE TABLE DBServers (
       ServerId             int NOT NULL,
       DatabaseId           int NOT NULL
)
go


ALTER TABLE DBServers
       ADD PRIMARY KEY CLUSTERED (ServerId ASC, DatabaseId ASC)
go


CREATE TABLE DBUserAccounts (
       DBUserAccountId      int NOT NULL,
       JobId                int NOT NULL,
       ServerId             int NOT NULL,
       DatabaseId           int NOT NULL,
       DBAccountName        char(60) NOT NULL,
       Security_1           binary(50) NULL,
       Security_2           binary(8) NULL,
       Security_3           binary(8) NULL,
       Security_4           int NULL
)
go


ALTER TABLE DBUserAccounts
       ADD PRIMARY KEY CLUSTERED (DBUserAccountId ASC, JobId ASC, 
              ServerId ASC, DatabaseId ASC)
go


CREATE TABLE Files (
       FileId               int NOT NULL,
       FTPServerId          integer NOT NULL,
       Get_Put              char(3) NOT NULL,
       FileName             varchar(1000) NOT NULL
)
go


ALTER TABLE Files
       ADD PRIMARY KEY CLUSTERED (FileId ASC, FTPServerId ASC)
go


CREATE TABLE FtpServers (
       FTPServerId          integer IDENTITY(1,1),
       AppId                int NULL,
       ServerId             int NULL,
       FTPHostCommonName    varchar(100) NOT NULL,
       FTPHostFullName      varchar(200) NOT NULL,
       FTPHostSuffix        varchar(100) NULL,
       FTPUserName          char(30) NULL,
       FTPSecurity_1        binary(50) NULL,
       FTPSecurity_2        binary(8) NULL,
       FTPSecurity_3        binary(8) NULL,
       FTPSecurity_4        int NULL,
       FTPLocationSubDirectory varchar(1000) NULL
)
go


ALTER TABLE FtpServers
       ADD PRIMARY KEY CLUSTERED (FTPServerId ASC)
go


CREATE TABLE JobFiles (
       JobId                int NOT NULL,
       ServerId             int NOT NULL,
       DatabaseId           int NOT NULL,
       FileId               int NOT NULL,
       FTPServerId          integer NOT NULL
)
go


ALTER TABLE JobFiles
       ADD PRIMARY KEY CLUSTERED (JobId ASC, ServerId ASC, DatabaseId ASC, 
              FileId ASC, FTPServerId ASC)
go


CREATE TABLE Jobs (
       JobId                int NOT NULL,
       ServerId             int NOT NULL,
       DatabaseId           int NOT NULL,
       JobName              char(40) NOT NULL,
       StartAtStep          int NULL
)
go


ALTER TABLE Jobs
       ADD PRIMARY KEY CLUSTERED (JobId ASC, ServerId ASC, DatabaseId ASC)
go


CREATE TABLE Servers (
       ServerId             int NOT NULL,
       ServerName           char(30) NOT NULL
)
go


ALTER TABLE Servers
       ADD PRIMARY KEY CLUSTERED (ServerId ASC)
go


CREATE TABLE UserAccess (
       DomainUserId         char(20) NOT NULL,
       DBUserAccountId      int NOT NULL,
       JobId                int NOT NULL,
       ServerId             int NOT NULL,
       DatabaseId           int NOT NULL,
       AccessLevel          bit NOT NULL
)
go


ALTER TABLE UserAccess
       ADD PRIMARY KEY CLUSTERED (DomainUserId ASC, DBUserAccountId ASC, 
              JobId ASC, ServerId ASC, DatabaseId ASC)
go


CREATE TABLE UserAccessFiles (
       DomainUserId         char(20) NOT NULL,
       FileId               int NOT NULL,
       FTPServerId          integer NOT NULL
)
go


ALTER TABLE UserAccessFiles
       ADD PRIMARY KEY CLUSTERED (DomainUserId ASC, FileId ASC, 
              FTPServerId ASC)
go


CREATE TABLE Users (
       DomainUserId         char(20) NOT NULL,
       DomainUserName       varchar(50) NULL
)
go


ALTER TABLE Users
       ADD PRIMARY KEY CLUSTERED (DomainUserId ASC)
go

CREATE VIEW DBUserAccountDisplays AS
       SELECT DBUserAccounts.DBUserAccountId, DBUserAccounts.JobId, Jobs.JobName, DBUserAccounts.ServerId, Servers.ServerName, DBUserAccounts.DatabaseId, Databases.DatabaseName, DBUserAccounts.DBAccountName, DBUserAccounts.Security_1, DBUserAccounts.Security_2, DBUserAccounts.Security_3, DBUserAccounts.Security_4
       FROM Databases, DBUserAccounts, Jobs, Servers
       WHERE        Jobs.JobId = DBUserAccounts.JobId
and Servers.ServerId = DBUserAccounts.ServerId
and Databases.DatabaseId = DBUserAccounts.DatabaseId
go


ALTER TABLE ApplicationDatabases
       ADD FOREIGN KEY (DatabaseId)
                             REFERENCES Databases  (DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE ApplicationDatabases
       ADD FOREIGN KEY (AppId)
                             REFERENCES Applications  (AppId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE DBServers
       ADD FOREIGN KEY (DatabaseId)
                             REFERENCES Databases  (DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE DBServers
       ADD FOREIGN KEY (ServerId)
                             REFERENCES Servers  (ServerId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE DBUserAccounts
       ADD FOREIGN KEY (JobId, ServerId, DatabaseId)
                             REFERENCES Jobs  (JobId, ServerId, 
              DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE Files
       ADD FOREIGN KEY (FTPServerId)
                             REFERENCES FtpServers  (FTPServerId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE FtpServers
       ADD FOREIGN KEY (ServerId)
                             REFERENCES Servers  (ServerId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE FtpServers
       ADD FOREIGN KEY (AppId)
                             REFERENCES Applications  (AppId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE JobFiles
       ADD FOREIGN KEY (JobId, ServerId, DatabaseId)
                             REFERENCES Jobs  (JobId, ServerId, 
              DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE JobFiles
       ADD FOREIGN KEY (FileId, FTPServerId)
                             REFERENCES Files  (FileId, FTPServerId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE Jobs
       ADD FOREIGN KEY (ServerId, DatabaseId)
                             REFERENCES DBServers  (ServerId, 
              DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE UserAccess
       ADD FOREIGN KEY (DomainUserId)
                             REFERENCES Users  (DomainUserId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE UserAccess
       ADD FOREIGN KEY (DBUserAccountId, JobId, ServerId, DatabaseId)
                             REFERENCES DBUserAccounts  (
              DBUserAccountId, JobId, ServerId, DatabaseId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE UserAccessFiles
       ADD FOREIGN KEY (DomainUserId)
                             REFERENCES Users  (DomainUserId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


ALTER TABLE UserAccessFiles
       ADD FOREIGN KEY (FileId, FTPServerId)
                             REFERENCES Files  (FileId, FTPServerId)
                             ON DELETE NO ACTION
                             ON UPDATE NO ACTION
go


CREATE PROCEDURE p_GetAllForDomainUser
@DomainUserId 	char(20)

 AS

Select a.AppId, a.AppName, f.ServerId, fs.ServerName, d.ServerId, s.ServerName, j.JobId
	, j.JobName, u.DBUserAccountId, u.DBAccountName -- ,u.DBAccountPassword
from UserAccess p
	, DBUserAccounts u
	, Jobs j
	, DBServers d
	, Servers s
                , FtpServers f
                , Servers fs
                , ApplicationDatabases ad
	, Applications a
where 	p.DomainUserId =		@DomainUserId
  and   p.AccessLevel =			1
  and   u.DBUserAccountId =		p.DBUserAccountId
  and   u.JobId =				p.JobId
  and   u.ServerId =			p.ServerId
  and   u.DatabaseId =				p.DatabaseId
  and   j.JobId =				u.JobId
  and   j.ServerId =			u.ServerId
  and   j.DatabaseId =				u.DatabaseId
  and   d.ServerId =			j.ServerId
  and   d.DatabaseId =				j.DatabaseId
  and	s.ServerId =			d.ServerId
  and  ad.DatabaseId = d.DatabaseId
  and   a.Appid =				ad.Appid
  and   f.AppId =   a.AppId
  and  s.ServerId =  f.ServerId
go

CREATE PROCEDURE up_vwDBUserAccountDisplays_Select

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select DBUserAccountId
	,	JobId
	,	JobName
	,	ServerId
	,	ServerName
	,	DatabaseId
	,	DatabaseName
	,	DBAccountName
	,	Security_1
	,	Security_2
	,	Security_3
	,	Security_4
from	DBUserAccountDisplays

select @TempError = @@error

if @TempError <> 0 
      --Log error
      BEGIN
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_vwDBUserAccountDisplays_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      END         

return (0)

LogError:
-- to do. write to error log
return(-99)
go


CREATE PROCEDURE up_tblApplicationDatabases_Delete
(
@AppId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 AppId from ApplicationDatabases WITH (NOLOCK)
           where  AppId = @AppId
			and   DatabaseId = @DatabaseId)

  begin
  
     begin transaction
     
     delete from ApplicationDatabases WITH (ROWLOCK)
     where  AppId = @AppId
	  and   DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplicationDatabases_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblApplicationDatabases_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in ApplicationDatabases'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblApplicationDatabases_Insert
(
@AppId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into ApplicationDatabases
 (AppId, DatabaseId)
values (@AppId, @DatabaseId)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblApplicationDatabases_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @AppId = (select scope_identity())
--select @AppId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblApplicationDatabases_Select
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select AppId
	, DatabaseId
from	ApplicationDatabases

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplicationDatabases_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblApplicationDatabases_SelectByPriKey
(
@AppId int,
@DatabaseId int,
@ErrorMessage varchar(1000)
)

as

declare @TempError       int,
        @ErrorCode       int

select AppId
	, DatabaseId
from	ApplicationDatabases
where	AppId = @AppId
 and    DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplicationDatabases_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblApplications_select AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	AppId
  ,  	AppName
from	Applications



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplications_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblApplications_Insert 
(
@AppId int,
@AppName char(40),
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Applications
 (AppId, AppName)
values (@AppId, @AppName)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblApplications_insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @jbeID = (select scope_identity())
--select @AppID = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblApplications_SelectCombined 
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	AppId
  ,  	AppName
  ,  cast(AppId as varchar(6)) + ' ' + AppName as 'Combined'
from	Applications



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplications_selectCombined'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblApplications_Update 
(
@AppId int,
@AppName char(40),
@ErrorMessage varchar(1000) output
)

AS
begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
        
If exists (select top 1 AppID from Applications WITH (ROWLOCK)
         where  AppID = @AppID)

begin

update Applications WITH (ROWLOCK)
set AppName = @AppName
where AppId = @AppId


select @TempError = @@error

if @TempError <> 0 
  --Log error
  begin
     select @ErrorCode = @TempError
     select @ErrorMessage = 'Error in Procedure: up_tblApplications_update '
     select @ErrorMessage = @ErrorMessage + description
     from master.dbo.sysmessages
     where error = @ErrorCode
     goto LogError
  end         

     return (0)

  end
else
  begin
    select @ErrorMessage = 'Error in Procedure: up_tblApplications_update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Applications'
    return(-90)
  end


LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblApplications_Delete
(
@AppId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 AppID from Applications WITH (NOLOCK)
           where  AppID = @AppID)

  begin
  
     begin transaction
     
     delete from Applications WITH (ROWLOCK)
     where  AppID = @AppID

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplications_delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
          rollback transaction
          goto LogError
       end         



     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblApplications_delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Applications'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblApplications_SelectByPriKey
(
@AppId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select AppId
	, AppName
from	Applications
where	AppId = @AppId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblApplications_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDatabases_Delete
(
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DatabaseId from Databases WITH (NOLOCK)
           where  DatabaseId = @DatabaseId)

  begin
  
     begin transaction
     
     delete from Databases WITH (ROWLOCK)
     where  DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDatabases_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblDatabases_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Databases'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblDatabases_Insert
(
@DatabaseId int,
@DatabaseName char(40),
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Databases
 (DatabaseId, DatabaseName)
values (@DatabaseId, @DatabaseName)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblDatabases_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @DatabaseID = (select scope_identity())
--select @DatabaseId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblDatabases_Select
 AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select	DatabaseId
  ,		DatabaseName
from	Databases

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDatabases_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDatabases_Update
(
@DatabaseId int,
@DatabaseName char(40),
@ErrorMessage varchar(1000) output
)

AS

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
        
If exists (select top 1 DatabaseId from Databases WITH (ROWLOCK)
         where  DatabaseId = @DatabaseId)

	begin

	update Databases WITH (ROWLOCK)
	set DatabaseName = @DatabaseName
	where DatabaseId = @DatabaseId

	select @TempError = @@error

	if @TempError <> 0 
		begin
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblDatabases_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		end         

	return (0)

	end
else
	begin
    select @ErrorMessage = 'Error in Procedure: up_tblDatabases_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Databases'
    return(-90)
	end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblDatabases_SelectByPriKey
(
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select DatabaseId
	, DatabaseName
from	Databases
where	DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDatabases_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDatabases_SelectCombined

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	DatabaseId
  ,  	DatabaseName
  ,  cast(DatabaseId as varchar(6)) + ' ' + DatabaseName as 'Combined'
from	Databases



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDatabases_selectCombined'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDBServers_Delete
(
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 ServerID from DBServers WITH (NOLOCK)
           where  ServerID = @ServerID
            and   DatabaseId = @DatabaseId)

  begin
  
     begin transaction
     
     delete from DBServers WITH (ROWLOCK)
     where  ServerID = @ServerID
      and   DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBServers_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblDBServers_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in DBServers'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblDBServers_Insert
(
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into DBServers
 (ServerId, DatabaseId)
values (@ServerId, @DatabaseId)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblDBServers_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @DatabaseId = (select scope_identity())
--select @ServerID = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblDBServers_Select

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select	ServerId
  ,  	DatabaseId
from	DBServers

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBServers_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDBServers_SelectCombined
AS
set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select	ServerId
  ,  	DatabaseId
  ,  cast(ServerId as varchar(6)) + ' ' + cast(DatabaseId as varchar(6)) as 'Combined'
from	DBServers



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBServers_SelectCombined'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDBServers_SelectByPriKey
(
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select ServerId
	, DatabaseId
from	DBServers
where	ServerId = @ServerId
 and	DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBServers_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDBUserAccounts_Delete
(
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DBUserAccountId from DBUserAccounts WITH (NOLOCK)
           where  DBUserAccountId = @DBUserAccountId
		    and   JobId = @JobId
			and   ServerId = @ServerId
            and   DatabaseId = @DatabaseId)


  begin
  
     begin transaction
     
     delete from DBUserAccounts WITH (ROWLOCK)
     where  DBUserAccountId = @DBUserAccountId
	  and   JobId = @JobId
	  and   ServerId = @ServerId
      and   DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in DBUserAccounts'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblDBUserAccounts_Insert
(
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@DBAccountName char(20),
@Security_1 binary(50),
@Security_2 binary(8),
@Security_3 binary(8),
@Security_4 int,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into DBUserAccounts
 (DBUserAccountId, JobId, ServerId, DatabaseId, DBAccountName, Security_1, Security_2, Security_3, Security_4)
values (@DBUserAccountId, @JobId, @ServerId, @DatabaseId, @DBAccountName, @Security_1, @Security_2, @Security_3, @Security_4)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @DatabaseId = (select scope_identity())
--select @DBUserAccountId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblDBUserAccounts_Select
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select	DBUserAccountId
	, JobId
	, ServerId
	, DatabaseId
	, DBAccountName
	, Security_1
                , Security_2
                , Security_3
                , Security_4
from	DBUserAccounts

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblDBUserAccounts_Update
(
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@DBAccountName char(20),
@Security_1 binary(50),
@Security_2 binary(8),
@Security_3 binary(8),
@Security_4 int,
@ErrorMessage varchar(1000) output
)

AS
begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DBUserAccountId from DBUserAccounts WITH (ROWLOCK)
         where  DBUserAccountId = @DBUserAccountId
			and JobId = @JobId
			and ServerId = @ServerId
			and DatabaseId = @DatabaseId)

	begin

	update DBUserAccounts WITH (ROWLOCK)
	set		DBAccountName = @DBAccountName
	 ,		Security_1 = @Security_1
	 ,		Security_2 = @Security_2
	 ,		Security_3 = @Security_3
                 ,                              Security_4 = @Security_4
    where	DBUserAccountId = @DBUserAccountId
	 and	JobId = @JobId
	 and	ServerId = @ServerId
	 and	DatabaseId = @DatabaseId

	select @TempError = @@error

	if @TempError <> 0 
		begin
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		end         

	return (0)

	end
else
	begin
    select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in DBUserAccounts'
    return(-90)
	end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblDBUserAccounts_SelectByPriKey
(
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select DBUserAccountId
	, JobId
	, ServerId
	, DatabaseId
	, DBAccountName
	, Security_1
                , Security_2
                , Security_3
                , Security_4
from	DBUserAccounts
where	DBUserAccountId = @DBUserAccountId
 and	JobId = @JobId
 and	ServerId = @ServerId
 and	DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblDBUserAccounts_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblFiles_Delete
(
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 FileId from Files WITH (NOLOCK)
           where  FileId = @FileId
		and   FTPServerId = @FTPServerId
           )

  begin
  
     begin transaction
     
     delete from Files WITH (ROWLOCK)
     where  FileId = @FileId
	  and   FTPServerId = @FTPServerId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFiles_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblFiles_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Files'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblFiles_Insert
(
@FileId int,
@FTPServerId int,
@Get_Put char(3),
@FileName varchar(1000),
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Files
 (FileId, FTPServerId, Get_Put, FileName)
values (@FileId, @FTPServerId, @Get_Put, @FileName)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblFiles_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @FileId = (select scope_identity())
--select @FileId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblFiles_Select
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select FileId
	, FTPServerId
	, Get_Put
	, FileName
from	Files

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFiles_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblFiles_Update
(
@FileId int,
@FTPServerId int,
@Get_Put char(3),
@FileName varchar(1000),
@ErrorMessage varchar(1000) output
)

AS
begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 FileId from Files WITH (ROWLOCK)
           where  FileId = @FileId
		and FTPServerId = @FTPServerId)

	begin

	update Files WITH (ROWLOCK)
	set		Get_Put = @Get_Put
	 ,		FileName = @FileName
    where	FileId = @FileId
	 and	FTPServerId = @FTPServerId

	select @TempError = @@error

	if @TempError <> 0 
		begin
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblFiles_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		end         

	return (0)

	end
else
	begin
    select @ErrorMessage = 'Error in Procedure: up_tblFiles_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Files'
    return(-90)
	end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblFiles_SelectByPriKey
(
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select FileId
	, FTPServerId
	, Get_Put
	, FileName
from	Files
where	FileId = @FileId
 and	FTPServerId = @FTPServerId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFiles_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblFTPServers_Delete

(
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 FTPServerID from FTPServers WITH (NOLOCK)
           where  FTPServerID = @FTPServerID
   )

  begin
  
     begin transaction
     
     delete from FTPServers WITH (ROWLOCK)
     where  FTPServerID = @FTPServerID


     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFTPServers_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblFTPServers_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in FTPServers'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblFTPServers_Insert
(
@FTPServerId int output,
@AppId int,
@ServerId int,
@FTPHostFullName varchar(200),
@FTPHostCommonName varchar(100),
@FTPHostSuffix varchar(100),
@FTPUserName char(30),
@FTPSecurity_1 binary(50),
@FTPSecurity_2 binary(8),
@FTPSecurity_3 binary(8),
@FTPSecurity_4 int,
@FTPLocationSubDirectory varchar(1000),
@ErrorMessage varchar(1000) output
)

AS

BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into FtpServers
 (ServerId, AppId, FTPHostFullName, FTPHostCommonName, FTPHostSuffix, FTPUserName, FTPSecurity_1, FTPSecurity_2, FTPSecurity_3, FTPSecurity_4, FTPLocationSubDirectory)
values (@ServerId, @AppId, @FTPHostFullName, @FTPHostCommonName, @FTPHostSuffix, @FTPUserName, @FTPSecurity_1, @FTPSecurity_2, @FTPSecurity_3, @FTPSecurity_4, @FTPLocationSubDirectory)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     BEGIN
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblFtpServers_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     END         

select @FTPServerId = (select scope_identity())
--select @ServerId = @@identity

return (0)

LogError:
-- to do. write to error log

return(-99)
END
go

CREATE PROCEDURE up_tblFTPServers_Select

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select FTPServerId
	,	AppId
                ,               ServerId
	,	FTPHostFullName
	,	FTPHostCommonName
	,	FTPHostSuffix
	,	FTPUserName
	,	FTPSecurity_1
, FTPSecurity_2
, FTPSecurity_3
, FTPSecurity_4
	,	FTPLocationSubDirectory
from	FtpServers

select @TempError = @@error

if @TempError <> 0 
      --Log error
      BEGIN
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFtpServers_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      END         

return (0)

LogError:
-- to do. write to error log
return(-99)
go

CREATE PROCEDURE up_tblFTPServers_Update
(
@FTPServerId int,
@ServerId int,
@AppId int,
@FTPHostFullName varchar(200),
@FTPHostCommonName varchar(100),
@FTPHostSuffix varchar(100),
@FTPUserName char(30),
@FTPSecurity_1 binary(50),
@FTPSecurity_2 binary(8),
@FTPSecurity_3 binary(8),
@FTPSecurity_4 int,
@FTPLocationSubDirectory varchar(1000),
@ErrorMessage varchar(1000) output
)

AS

BEGIN

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 FTPServerId from FtpServers WITH (ROWLOCK)
           where  FTPServerId = @FTPServerId
		)

	BEGIN

	update FtpServers WITH (ROWLOCK)
	set		AppId = @AppId
                                ,               ServerId = @ServerId
                                ,               FTPHostFullName = @FTPHostFullName
		,	FTPHostCommonName = @FTPHostCommonName
		,	FTPHostSuffix = @FTPHostSuffix
		,	FTPUserName = @FTPUserName
		,	FTPSecurity_1 = @FTPSecurity_1
, FTPSecurity_2 = @FTPSecurity_2
, FTPSecurity_3 = @FTPSecurity_3
, FTPSecurity_4 = @FTPSecurity_4
		,	FTPLocationSubDirectory = @FTPLocationSubDirectory
    where	FTPServerId = @FTPServerId

	select @TempError = @@error

	if @TempError <> 0 
		BEGIN
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblFtpServers_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		END         

	return (0)

	END
else
	BEGIN
    select @ErrorMessage = 'Error in Procedure: up_tblFtpServers_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in FtpServers'
    return(-90)
	END

LogError:
-- to do. write to error log

return(-99)

END
go

CREATE PROCEDURE up_tblFTPServers_SelectByPriKey
(
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select FTPServerId
	,	AppId
                ,               ServerId
	,	FTPHostFullName
	,	FTPHostCommonName
	,	FTPHostSuffix
	,	FTPUserName
	,	FTPSecurity_1
, FTPSecurity_2
, FTPSecurity_3
, FTPSecurity_4
	,	FTPLocationSubDirectory
from	FtpServers
where	FTPServerId = @FTPServerId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      BEGIN
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblFtpServers_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      END         

return (0)

LogError:
-- to do. write to error log
return(-99)
go

CREATE PROCEDURE up_tblJobFiles_Delete 

(
@JobId int,
@ServerId int,
@DatabaseId int,
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 JobId from JobFiles WITH (NOLOCK)
           where JobId = @JobId
			and ServerId = @ServerId
			and DatabaseId = @DatabaseId
			and FileId = @FileId
			and FTPServerId = @FTPServerId
			)

  begin
  
     begin transaction
     
     delete from JobFiles WITH (ROWLOCK)
     where  JobId = @JobId
	  and ServerId = @ServerId
	  and DatabaseId = @DatabaseId
	  and FileId = @FileId
	  and FTPServerId = @FTPServerId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobFiles_Delete '
          select @ErrorMessage = @ErrorMessage + description
          from master.dbo.sysmessages
          where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblJobFiles_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in JobFiles'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblJobFiles_Insert

(
@JobId int,
@ServerId int,
@DatabaseId int,
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

AS

BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into JobFiles
 (JobId, ServerId, DatabaseId, FileId, FTPServerId)
values (@JobId, @ServerId, @DatabaseId, @FileId, @FTPServerId)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     BEGIN
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblJobFiles_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     END         

--select @JobId = (select scope_identity())
--select @JobId = @@identity

return (0)

LogError:
-- to do. write to error log

return(-99)
END
go

CREATE PROCEDURE up_tblJobFiles_Select 

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select JobId
	,	ServerId
	,	DatabaseId
	,	FileId
	,	FTPServerId
from	JobFiles

select @TempError = @@error

if @TempError <> 0 
      --Log error
      BEGIN
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobFiles_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      END         

return (0)

LogError:
-- to do. write to error log
return(-99)
go

CREATE PROCEDURE up_tblJobFiles_SelectByPriKey
(
@JobId int,
@ServerId int,
@DatabaseId int,
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select JobId
	,	ServerId
	,	DatabaseId
	,	FileId
	,	FTPServerId
from	JobFiles
where JobId = @JobId
 and ServerId = @ServerId
 and DatabaseId = @DatabaseId
 and FileId = @FileId
 and FTPServerId = @FTPServerId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      BEGIN
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobFiles_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      END         

return (0)

LogError:
-- to do. write to error log
return(-99)
go

CREATE PROCEDURE up_tblJobs_Delete
(
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 JobId from Jobs WITH (NOLOCK)
           where  JobId = @JobId
	and   ServerId = @ServerId
            and   DatabaseId = @DatabaseId)

  begin
  
     begin transaction
     
     delete from Jobs WITH (ROWLOCK)
     where  JobId = @JobId
      and   ServerId = @ServerId
      and   DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobs_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblJobs_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Jobs'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblJobs_Insert
(
@JobId int,
@ServerId int,
@DatabaseId int,
@JobName char(40),
@StartAtStep int,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Jobs
 (JobId,  ServerId, DatabaseId, JobName, StartAtStep)
values (@JobId, @ServerId, @DatabaseId, @JobName, @StartAtStep)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblJobs_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @JobID = (select scope_identity())
--select @JobId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblJobs_Select 
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select JobId
	, ServerId
	, DatabaseId
	, JobName
	, StartAtStep
from	Jobs

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobs_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblJobs_Update
(
@JobId int,
@ServerId int,
@DatabaseId int,
@JobName char(40),
@StartAtStep int,
@ErrorMessage varchar(1000) output
)

AS

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 JobId from Jobs WITH (ROWLOCK)
           where  JobId = @JobId
			and ServerId = @ServerId
			and DatabaseId = @DatabaseId
            )
	begin

	update Jobs WITH (ROWLOCK)
	set		JobName = @JobName
	 ,		StartAtStep = @StartAtStep
    where	JobId = @JobId
	 and	ServerId = @ServerId
	 and	DatabaseId = @DatabaseId

	select @TempError = @@error

	if @TempError <> 0 
		begin
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblJobs_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		end         

	return (0)

	end
else
	begin
    select @ErrorMessage = 'Error in Procedure: up_tblJobs_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Jobs'
    return(-90)
	end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblJobs_SelectByPriKey
(
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select JobId
	, ServerId
	, DatabaseId
	, JobName
	, StartAtStep
from	Jobs
where	JobId = @JobId
 and	ServerId = @ServerId
 and	DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblJobs_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblServers_Insert
(
@ServerId int,
@ServerName char(30),
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Servers
 (ServerId, ServerName)
values (@ServerId, @ServerName)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblServers_insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @jbeID = (select scope_identity())
--select @AppID = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblServers_Delete 

(
@ServerId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 ServerID from Servers WITH (NOLOCK)
           where  ServerID = @ServerID)

  begin
  
     begin transaction
     
     delete from Servers WITH (ROWLOCK)
     where  ServerID = @ServerID

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblServers_delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
          rollback transaction
          goto LogError
       end         



     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblServers_delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Servers'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblServers_Select

AS

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	ServerId
  ,  	ServerName
from	Servers



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblServers_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblServers_SelectCombined

AS
set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	ServerId
  ,  	ServerName
  ,  cast(ServerId as varchar(6)) + ' ' + ServerName as 'Combined'
from	Servers



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblServers_SelectCombined'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblServers_Update 
(
@ServerId int,
@ServerName char(30),
@ErrorMessage varchar(1000) output
)

AS

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
        
If exists (select top 1 ServerID from Servers WITH (ROWLOCK)
         where  ServerID = @ServerId)

begin

update Servers WITH (ROWLOCK)
set ServerName = @ServerName
where ServerId = @ServerId


select @TempError = @@error

if @TempError <> 0 
  --Log error
  begin
     select @ErrorCode = @TempError
     select @ErrorMessage = 'Error in Procedure: up_tblServers_update '
     select @ErrorMessage = @ErrorMessage + description
     from master.dbo.sysmessages
     where error = @ErrorCode
     goto LogError
  end         

     return (0)

  end
else
  begin
    select @ErrorMessage = 'Error in Procedure: up_tblServers_update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Servers'
    return(-90)
  end


LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblServers_SelectByPriKey
(
@ServerId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select ServerId
	, ServerName
from	Servers
where	ServerId = @ServerId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblServers_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUserAccess_Delete
(
@DomainUserId char(20),
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DomainUserId from UserAccess WITH (NOLOCK)
           where  DomainUserId = @DomainUserId
		    and   DBUserAccountId = @DBUserAccountId
		    and   JobId = @JobId
		and   ServerId = @ServerId
            and   DatabaseId = @DatabaseId)

  begin
  
     begin transaction
     
     delete from UserAccess WITH (ROWLOCK)
     where  DomainUserId = @DomainUserId
	  and	DBUserAccountId = @DBUserAccountId
	  and   JobId = @JobId
	  and   ServerId = @ServerId
      and   DatabaseId = @DatabaseId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in UserAccess'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblUserAccess_Insert
(
@DomainUserId char(20),
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@AccessLevel bit,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into UserAccess
 (DomainUserId, DBUserAccountId, JobId, ServerId, DatabaseId, AccessLevel)
values (@DomainUserId, @DBUserAccountId, @JobId, @ServerId, @DatabaseId, @AccessLevel)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @DomainUserID = (select scope_identity())
--select @DomainUserId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblUserAccess_Select

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select DomainUserId
	, DBUserAccountId
	, JobId
	, ServerId
	, DatabaseId
	, AccessLevel
from	UserAccess

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUserAccess_SelectByPriKey
(
@DomainUserId char(20),
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select DomainUserId
	, DBUserAccountId
	, JobId
	, ServerId
	, DatabaseId
	, AccessLevel
from	UserAccess
where	DomainUserId = @DomainUserId
 and	DBUserAccountId = @DBUserAccountId
 and	JobId = @JobId
 and	ServerId = @ServerId
 and	DatabaseId = @DatabaseId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUserAccess_Update
(
@DomainUserId char(10),
@DBUserAccountId int,
@JobId int,
@ServerId int,
@DatabaseId int,
@AccessLevel bit,
@ErrorMessage varchar(1000) output
)

AS
begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DomainUserId from UserAccess WITH (ROWLOCK)
           where  DomainUserId = @DomainUserId
			and DBUserAccountId = @DBUserAccountId
			and JobId = @JobId
			and ServerId = @ServerId
			and DatabaseId = @DatabaseId)

	begin

	update UserAccess WITH (ROWLOCK)
	set		AccessLevel = @AccessLevel
    where	DomainUserId = @DomainUserId
	 and	DBUserAccountId = @DBUserAccountId
	 and	JobId = @JobId
	 and	ServerId = @ServerId
	 and	DatabaseId = @DatabaseId

	select @TempError = @@error

	if @TempError <> 0 
		begin
		select @ErrorCode = @TempError
		select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_Update '
		select @ErrorMessage = @ErrorMessage + description
		from master.dbo.sysmessages
		where error = @ErrorCode
		
		goto LogError
		end         

	return (0)

	end
else
	begin
    select @ErrorMessage = 'Error in Procedure: up_tblUserAccess_Update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in UserAccess'
    return(-90)
	end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblUserAccessFiles_Delete
(
@DomainUserId char(20),
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DomainUserId from UserAccessFiles WITH (NOLOCK)
           where  DomainUserId = @DomainUserId
		    and   FileId = @FileId
		and   FTPServerId = @FTPServerId)

  begin
  
     begin transaction
     
     delete from UserAccessFiles WITH (ROWLOCK)
     where  DomainUserId = @DomainUserId
	  and	FileId = @FileId
	  and   FTPServerId = @FTPServerId

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccessFiles_Delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
			   
          rollback transaction
          goto LogError
       end         

     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblUserAccessFiles_Delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in UserAccessFiles'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblUserAccessFiles_Insert
(
@DomainUserId char(20),
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into UserAccessFiles
 (DomainUserId, FileId, FTPServerId)
values (@DomainUserId, @FileId, @FTPServerId)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblUserAccessFiles_Insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @FileId = (select scope_identity())
--select @FileId = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblUserAccessFiles_SelectByPriKey
(
@DomainUserId char(20),
@FileId int,
@FTPServerId int,
@ErrorMessage varchar(1000) output
)

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select DomainUserId
	, FileId
	, FTPServerId
from	UserAccessFiles
where	DomainUserId = @DomainUserId
 and	FileId = @FileId
 and	FTPServerId = @FTPServerId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccessFiles_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUserAccessFiles_Select
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)

select DomainUserId
	, FileId
	, FTPServerId
from	UserAccessFiles

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUserAccessFiles_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUsers_Delete 
(
@DomainUserId int,
@ErrorMessage varchar(1000) output
)

as

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
If exists (select top 1 DomainUserID from Users WITH (NOLOCK)
           where  DomainUserID = @DomainUserID)

  begin
  
     begin transaction
     
     delete from Users WITH (ROWLOCK)
     where  DomainUserID = @DomainUserID

     select @TempError = @@error

     if @TempError <> 0 

       --Log error
       begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUsers_delete '
          select @ErrorMessage = @ErrorMessage + description
               from master.dbo.sysmessages
               where error = @ErrorCode
          rollback transaction
          goto LogError
       end         



     commit transaction       
     return (0)
  end

else

  begin
     select @ErrorMessage = 'Error in Procedure: up_tblUsers_delete '
     select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Users'
     return (-90)
  end

LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblUsers_Insert
(
@DomainUserId int,
@DomainUserName char(50),
@ErrorMessage varchar(1000) output
)

AS
BEGIN
set nocount on

declare @TempError      int,
        @ErrorCode      int
                
Insert into Users
 (DomainUserId, DomainUserName)
values (@DomainUserId, @DomainUserName)

select @TempError = @@error

if @TempError <> 0 
     --Log error
     begin
        select @ErrorCode = @TempError
        select @ErrorMessage = 'Error in Procedure: up_tblUsers_insert'
        select @ErrorMessage = @ErrorMessage + description
             from master.dbo.sysmessages
             where error = @ErrorCode
        goto LogError
     end         

--select @AppID = (select scope_identity())
--select @DomainUserID = @@identity

return (0)

LogError:
-- write to error log

return(-99)
end
go

CREATE PROCEDURE up_tblUsers_Select 

 AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	DomainUserId
  ,  	DomainUserName
from	Users



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUsers_select'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUsers_SelectCombined

AS

set nocount on

declare @TempError       int,
        @ErrorCode       int,
        @ErrorMessage    varchar(1000)


        
select	DomainUserId
  ,  	DomainUserName
  ,  cast(DomainUserId as varchar(6)) + ' ' + DomainUserName as 'Combined'
from	Users



select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUsers_SelectCombined'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go

CREATE PROCEDURE up_tblUsers_Update
(
@DomainUserId int,
@DomainUserName char(50),
@ErrorMessage varchar(1000) output
)

AS

begin

set nocount on

declare @TempError        int,
        @ErrorCode        int
        
        
If exists (select top 1 DomainUserId from Users WITH (ROWLOCK)
         where  DomainUserID = @DomainUserId)

begin

update Users WITH (ROWLOCK)
set DomainUserName = @DomainUserName
where DomainUserId = @DomainUserId


select @TempError = @@error

if @TempError <> 0 
  --Log error
  begin
     select @ErrorCode = @TempError
     select @ErrorMessage = 'Error in Procedure: up_tblUsers_update '
     select @ErrorMessage = @ErrorMessage + description
     from master.dbo.sysmessages
     where error = @ErrorCode
     goto LogError
  end         

     return (0)

  end
else
  begin
    select @ErrorMessage = 'Error in Procedure: up_tblUsers_update '
    select @ErrorMessage = @ErrorMessage + 'Unable to locate row in Users'
    return(-90)
  end


LogError:
-- write to error log

return(-99)

end
go

CREATE PROCEDURE up_tblUsers_SelectByPriKey
(
@DomainUserId char(10),
@ErrorMessage varchar(1000) output
)
AS

set nocount on

declare @TempError       int,
        @ErrorCode       int

select DomainUserId
	, DomainUserName
from	Users
where	DomainUserId = @DomainUserId

select @TempError = @@error

if @TempError <> 0 
      --Log error
      begin
          select @ErrorCode = @TempError
          select @ErrorMessage = 'Error in Procedure: up_tblUsers_SelectByPriKey'
          select @ErrorMessage = @ErrorMessage + description
                from master.dbo.sysmessages
                where error = @ErrorCode
          goto LogError
      end         

return (0)

LogError:
-- write to error log
return(-99)
go


create trigger tD_Applications on Applications for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)

    if exists (
      select * from deleted,FtpServers
      where
        FtpServers.AppId = deleted.AppId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Applications because FtpServers exists.'
      goto error
    end

    if exists (
      select * from deleted,ApplicationDatabases
      where
        ApplicationDatabases.AppId = deleted.AppId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Applications because ApplicationDatabases exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Applications on Applications for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insAppId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(AppId)
  begin
    if exists (
      select * from deleted,FtpServers
      where
        FtpServers.AppId = deleted.AppId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Applications because FtpServers exists.'
      goto error
    end
  end

  if
    update(AppId)
  begin
    if exists (
      select * from deleted,ApplicationDatabases
      where
        ApplicationDatabases.AppId = deleted.AppId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Applications because ApplicationDatabases exists.'
      goto error
    end
  end


  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_Databases on Databases for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,DBServers
      where
        DBServers.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Databases because DBServers exists.'
      goto error
    end

    if exists (
      select * from deleted,ApplicationDatabases
      where
        ApplicationDatabases.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Databases because ApplicationDatabases exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Databases on Databases for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insDatabaseId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,DBServers
      where
        DBServers.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Databases because DBServers exists.'
      goto error
    end
  end

  if
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,ApplicationDatabases
      where
         ApplicationDatabases.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Databases because ApplicationDatabases exists.'
      goto error
    end
  end


  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_DBServers on DBServers for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,Jobs
      where
        Jobs.ServerId = deleted.ServerId and
        Jobs.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE DBServers because Jobs exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_DBServers on DBServers for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insServerId int, 
           @insDatabaseId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(ServerId) or
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,Jobs
      where
        Jobs.ServerId = deleted.ServerId and
        Jobs.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE DBServers because Jobs exists.'
      goto error
    end
  end


  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_DBUserAccounts on DBUserAccounts for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,UserAccess
      where
        UserAccess.DBUserAccountId = deleted.DBUserAccountId and
        UserAccess.JobId = deleted.JobId and
        UserAccess.ServerId = deleted.ServerId and
        UserAccess.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE DBUserAccounts because UserAccess exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_DBUserAccounts on DBUserAccounts for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insDBUserAccountId int, 
           @insJobId int, 
           @insServerId int, 
           @insDatabaseId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(DBUserAccountId) or
    update(JobId) or
    update(ServerId) or
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,UserAccess
      where
        UserAccess.DBUserAccountId = deleted.DBUserAccountId and
        UserAccess.JobId = deleted.JobId and
        UserAccess.ServerId = deleted.ServerId and
        UserAccess.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE DBUserAccounts because UserAccess exists.'
      goto error
    end
  end


  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_Files on Files for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,JobFiles
      where
        JobFiles.FileId = deleted.FileId and
        JobFiles.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Files because JobFiles exists.'
      goto error
    end

    if exists (
      select * from deleted,UserAccessFiles
      where
        UserAccessFiles.FileId = deleted.FileId and
        UserAccessFiles.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Files because UserAccessFiles exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Files on Files for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insFileId int, 
           @insFTPServerId integer,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(FileId) or
    update(FTPServerId)
  begin
    if exists (
      select * from deleted,JobFiles
      where
        JobFiles.FileId = deleted.FileId and
        JobFiles.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Files because JobFiles exists.'
      goto error
    end
  end

  if
    update(FileId) or
    update(FTPServerId)
  begin
    if exists (
      select * from deleted,UserAccessFiles
      where
        UserAccessFiles.FileId = deleted.FileId and
        UserAccessFiles.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Files because UserAccessFiles exists.'
      goto error
    end
  end

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_FtpServers on FtpServers for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,Files
      where
        Files.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE FtpServers because Files exists.'
      goto error
    end

    if exists (select * from deleted,Servers
      where
        deleted.ServerId = Servers.ServerId and
        not exists (
          select * from FtpServers
          where
            FtpServers.ServerId = Servers.ServerId
        )
    )
    begin
      select @errno  = 30010,
             @errmsg = 'Cannot DELETE last FtpServers because Servers exists.'
      goto error
    end

    if exists (select * from deleted,Applications
      where
        deleted.AppId = Applications.AppId and
        not exists (
          select * from FtpServers
          where
            FtpServers.AppId = Applications.AppId
        )
    )
    begin
      select @errno  = 30010,
             @errmsg = 'Cannot DELETE last FtpServers because Applications exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_FtpServers on FtpServers for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insFTPServerId integer,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(FTPServerId)
  begin
    if exists (
      select * from deleted,Files
      where
        Files.FTPServerId = deleted.FTPServerId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE FtpServers because Files exists.'
      goto error
    end
  end

  if
    update(ServerId)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,Servers
        where
          inserted.ServerId = Servers.ServerId
    select @nullcnt = count(*) from inserted where
      inserted.ServerId is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = 'Cannot UPDATE FtpServers because Servers does not exist.'
      goto error
    end
  end

  if
    update(AppId)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,Applications
        where
          inserted.AppId = Applications.AppId
    select @nullcnt = count(*) from inserted where
      inserted.AppId is null
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = 'Cannot UPDATE FtpServers because Applications does not exist.'
      goto error
    end
  end

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_Jobs on Jobs for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,JobFiles
      where
        JobFiles.JobId = deleted.JobId and
        JobFiles.ServerId = deleted.ServerId and
        JobFiles.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Jobs because JobFiles exists.'
      goto error
    end

    if exists (
      select * from deleted,DBUserAccounts
      where
        DBUserAccounts.JobId = deleted.JobId and
        DBUserAccounts.ServerId = deleted.ServerId and
        DBUserAccounts.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Jobs because DBUserAccounts exists.'
      goto error
    end

    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Jobs on Jobs for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insJobId int, 
           @insServerId int, 
           @insDatabaseId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(JobId) or
    update(ServerId) or
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,JobFiles
      where
        JobFiles.JobId = deleted.JobId and
        JobFiles.ServerId = deleted.ServerId and
        JobFiles.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Jobs because JobFiles exists.'
      goto error
    end
  end

  if
    update(JobId) or
    update(ServerId) or
    update(DatabaseId)
  begin
    if exists (
      select * from deleted,DBUserAccounts
      where
        DBUserAccounts.JobId = deleted.JobId and
        DBUserAccounts.ServerId = deleted.ServerId and
        DBUserAccounts.DatabaseId = deleted.DatabaseId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Jobs because DBUserAccounts exists.'
      goto error
    end
  end

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_Servers on Servers for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,FtpServers
      where
        FtpServers.ServerId = deleted.ServerId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Servers because FtpServers exists.'
      goto error
    end

    if exists (
      select * from deleted,DBServers
      where
        DBServers.ServerId = deleted.ServerId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Servers because DBServers exists.'
      goto error
    end


    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Servers on Servers for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insServerId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(ServerId)
  begin
    if exists (
      select * from deleted,FtpServers
      where
        FtpServers.ServerId = deleted.ServerId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Servers because FtpServers exists.'
      goto error
    end
  end

  if
    update(ServerId)
  begin
    if exists (
      select * from deleted,DBServers
      where
        DBServers.ServerId = deleted.ServerId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Servers because DBServers exists.'
      goto error
    end
  end

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_UserAccess on UserAccess for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insDomainUserId char(20), 
           @insDBUserAccountId int, 
           @insJobId int, 
           @insServerId int, 
           @insDatabaseId int,
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(DomainUserId)
  begin
    select @nullcnt = 0
    select @validcnt = count(*)
      from inserted,Users
        where
          inserted.DomainUserId = Users.DomainUserId
    
    if @validcnt + @nullcnt != @numrows
    begin
      select @errno  = 30007,
             @errmsg = 'Cannot UPDATE UserAccess because Users does not exist.'
      goto error
    end
  end

  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tD_Users on Users for DELETE as
begin
  declare  @errno   int,
           @errmsg  varchar(255)
    if exists (
      select * from deleted,UserAccessFiles
      where
        UserAccessFiles.DomainUserId = deleted.DomainUserId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Users because UserAccessFiles exists.'
      goto error
    end

    if exists (
      select * from deleted,UserAccess
      where
        UserAccess.DomainUserId = deleted.DomainUserId
    )
    begin
      select @errno  = 30001,
             @errmsg = 'Cannot DELETE Users because UserAccess exists.'
      goto error
    end

    return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

create trigger tU_Users on Users for UPDATE as
begin
  declare  @numrows int,
           @nullcnt int,
           @validcnt int,
           @insDomainUserId char(20),
           @errno   int,
           @errmsg  varchar(255)

  select @numrows = @@rowcount
  if
    update(DomainUserId)
  begin
    if exists (
      select * from deleted,UserAccessFiles
      where
        UserAccessFiles.DomainUserId = deleted.DomainUserId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Users because UserAccessFiles exists.'
      goto error
    end
  end

  if
    update(DomainUserId)
  begin
    if exists (
      select * from deleted,UserAccess
      where
        UserAccess.DomainUserId = deleted.DomainUserId
    )
    begin
      select @errno  = 30005,
             @errmsg = 'Cannot UPDATE Users because UserAccess exists.'
      goto error
    end
  end


  return
error:
    raiserror @errno @errmsg
    rollback transaction
end
go

